@@ -7,8 +7,6 @@ perftools.middleware.querycount
 """
 
 import logging
-import random
-import sys
 import threading
 
 from django.core.handlers.wsgi import WSGIRequest
@@ -65,7 +63,7 @@ class QueryCountLoggingMiddlewareTest(Base):
         self.application = application
         self.threshold = threshold
         self.stacks = stacks
-        self.logger = logger or logging.getLogger('perftools')
+        self.logger = logger or logging.getLogger(__name__)
         self.queries = queries
         super(QueryCountLoggingMiddlewareTest, self).__init__(application, **kwargs)
 
@@ -93,6 +91,6 @@ class QueryCountLoggingMiddlewareTest(Base):
             'data': {
                 'threshold': self.threshold,
                 'query_count': state.count,
-                'queries': state.queries
+                'queries': [(k, repr(v)) for k, v in state.queries],
             }
         })
\ No newline at end of file
